@@ -50,7 +50,7 @@ use Carp;
 use strict;
 use warnings;
 
-our $VERSION = '1.07';
+our $VERSION = '1.071';
 
 
 ##################################################
@@ -1722,6 +1722,21 @@ Returns the largest-valued item in the tree.
 Returns the smallest-valued item in the tree.
 
 
+=head2 pop_largest()
+
+ my $largest_thing = $avltree->pop_largest();
+
+Removes and returns the largest-valued item in the tree.
+
+
+=head2 pop_smallest()
+
+ my $smallest_thing = $avltree->pop_smallest();
+
+Removes and returns the smallest-valued item in the tree.
+
+
+
 =head2 iterator()
 
  my $it = $avltree->iterator();
